@@ -174,7 +174,7 @@ class ParametersCOSIM:
     def makeGenericIOPortFiles(self, CoilSections, CurrentFolder, CoSimFolder: str, PSpiceExecutable: str, LEDETExecutable: str,
                                t_0 = [0, 2e-5], t_end = [2e-5, 0.5], t_step_max = [[1e-5, 1e-5], [1e-5, 1e-5]],
                                relTolerance = [1e-4, None], absTolerance = [1, None], executionOrder = [1, 2],
-                               executeCleanRun = [True, True], N_LEDET = 1, SimulationNumber = [0], DistinctMagnets = 1, PSPICEinitialConditions = []):
+                               executeCleanRun = [True, True], N_LEDET = 1, QuenchMagnet = 0, SimulationNumber = [0], DistinctMagnets = 1, PSPICEinitialConditions = []):
 
         # Components which are used in the Ports
         Components = ["L", "CoilSections"]  # [0] = PSpice, [1]=LEDET
@@ -382,6 +382,10 @@ class ParametersCOSIM:
 
         struct_total = []
         for n in range(0, N_LEDET):
+            if n== QuenchMagnet and QuenchMagnet != 0:
+                quench = '_QUENCH'
+            else:
+                quench = ''
             if DistinctMagnets != 1:
                 DM = n+1
                 M_add = "M"+str(DM)+'_'
@@ -402,9 +406,9 @@ class ParametersCOSIM:
                                 cPPSpice = "V"
                             else:
                                 cPPSpice = couplingParameterPSpice[j][0][l][0]
-                            substruct_in["labels"] = [cPPSpice + "_field_"+M_add + str(i+1) + "_stim"]  # First Port for Field
+                            substruct_in["labels"] = [cPPSpice + "_field_"+M_add + str(i+1) + "_stim"+quench]  # First Port for Field
                         else:  # Second Port with circuit
-                            substruct_in["labels"] = ["V_circuit_" +M_add+ str(i+1) + "_stim"]
+                            substruct_in["labels"] = ["V_circuit_" +M_add+ str(i+1) + "_stim"+quench]
                         substruct_in["types"] = couplingParameterPSpice[j][0][l][1]
                         struct["inputs"].append(substruct_in)
 
